@@ -4,10 +4,11 @@
 import re
 import time
 import logging
+from typing import Tuple
 
 from tenacity import retry, TryAgain, stop_after_attempt, retry_if_exception_type
-from fossology.exceptions import FossologyApiError, AuthorizationError
-from fossology.obj import get_options
+from .obj import ReportFormat, Upload
+from .exceptions import FossologyApiError
 
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.DEBUG)
@@ -17,52 +18,40 @@ class Report:
     """Class dedicated to all "report" related endpoints"""
 
     @retry(retry=retry_if_exception_type(TryAgain), stop=stop_after_attempt(3))
-    def generate_report(self, upload, report_format=None, group=None):
+    def generate_report(self, upload: Upload, report_format: ReportFormat = None):
         """Generate a report for a given upload
 
         API Endpoint: GET /report
 
         :param upload: the upload which report will be generated
-        :param format: the report format (default: ReportFormat.READMEOSS)
-        :param group: the group name to choose while generating the report (default: None)
+        :param format: the report format (default ReportFormat.READMEOSS)
         :type upload: Upload
         :type format: ReportFormat
-        :type group: string
         :return: the report id
         :rtype: int
         :raises FossologyApiError: if the REST call failed
-        :raises AuthorizationError: if the user can't access the group
         """
         headers = {"uploadId": str(upload.id)}
         if report_format:
             headers["reportFormat"] = report_format.value
         else:
             headers["reportFormat"] = "readmeoss"
-        if group:
-            headers["groupName"] = group
 
         response = self.session.get(f"{self.api}/report", headers=headers)
-
         if response.status_code == 201:
             report_id = re.search("[0-9]*$", response.json()["message"])
             return report_id[0]
-
-        elif response.status_code == 403:
-            description = f"Generating report for upload {upload.id} {get_options(group)}not authorized"
-            raise AuthorizationError(description, response)
-
         elif response.status_code == 503:
             wait_time = response.headers["Retry-After"]
             logger.debug(f"Retry generate report after {wait_time} seconds")
             time.sleep(int(wait_time))
             raise TryAgain
-
         else:
-            description = f"Report generation for upload {upload.name} failed"
+            description = f"Report generation for upload {upload.uploadname} failed"
             raise FossologyApiError(description, response)
 
     @retry(retry=retry_if_exception_type(TryAgain), stop=stop_after_attempt(3))
-    def download_report(self, report_id, as_zip=False, group=None):
+    def download_report(self, report_id: int) -> Tuple[str, str]:
         """Download a report
 
         API Endpoint: GET /report/{id}
@@ -75,41 +64,28 @@ class Report:
         >>>
         >>> # Generate a report for upload 1
         >>> report_id = foss.generate_report(foss.detail_upload(1))
-        >>> report_content = foss.download_report(report_id, as_zip=True)
-        >>> with open(filename, "w+") as report_file:
+        >>> report_content, report_name = foss.download_report(report_id)
+        >>> with open(report_name, "w+") as report_file:
         >>>     report_file.write(report_content)
 
         :param report_id: the id of the generated report
-        :param as_zip: control if the report should be generated as ZIP file (default: False)
-        :param group: the group name to choose while downloading a specific report (default: None)
         :type report_id: int
-        :type as_zip: boolean
-        :type group: string
+        :return: the report content and the report name
+        :rtype: Tuple[str, str]
         :raises FossologyApiError: if the REST call failed
-        :raises AuthorizationError: if the user can't access the group
+        :raises TryAgain: if the report generation timed out after 3 retries
         """
-        if as_zip:
-            headers = {"Accept": "application/zip"}
-        else:
-            headers = {"Accept": "text/plain"}
-        if group:
-            headers["groupName"] = group
-
-        response = self.session.get(f"{self.api}/report/{report_id}", headers=headers)
+        response = self.session.get(f"{self.api}/report/{report_id}")
         if response.status_code == 200:
-            return response.text
-
-        elif response.status_code == 403:
-            description = (
-                f"Getting report {report_id} {get_options(group)}not authorized"
-            )
-            raise AuthorizationError(description, response)
-
+            content = response.headers["Content-Disposition"]
+            report_name_pattern = '(^attachment; filename=")(.*)("$)'
+            report_name = re.match(report_name_pattern, content).group(2)
+            return response.text, report_name
         elif response.status_code == 503:
             wait_time = response.headers["Retry-After"]
             logger.debug(f"Retry get report after {wait_time} seconds")
             time.sleep(int(wait_time))
             raise TryAgain
         else:
-            description = "Download of report {report_id} failed"
+            description = f"Download of report {report_id} failed"
             raise FossologyApiError(description, response)
